import { type IExporter, type IPlotModel, type IRenderContext, type ITextMeasurer } from 'oxyplot-js';
/**
 * Provides functionality to export plots to scalable vector graphics.
 */
export declare class SvgExporter implements IExporter {
    /**
     * Initializes a new instance of the SvgExporter class.
     */
    constructor();
    /**
     * Gets or sets the width (in user units) of the output area.
     */
    width: number;
    /**
     * Gets or sets the height (in user units) of the output area.
     */
    height: number;
    /**
     * Gets or sets a value indicating whether the xml headers should be included.
     */
    isDocument: boolean;
    /**
     * Gets or sets a value indicating whether to use a workaround for vertical text alignment to support renderers with limited support for the dominate-baseline attribute.
     */
    useVerticalTextAlignmentWorkaround: boolean;
    /**
     * Gets or sets the text measurer.
     */
    textMeasurer?: IRenderContext;
    /**
     * Exports the specified model to a stream.
     * @param model The model.
     * @param width The width (points).
     * @param height The height (points).
     * @param isDocument if set to true, the xml headers will be included (?xml and !DOCTYPE).
     * @param textMeasurer The text measurer.
     * @param useVerticalTextAlignmentWorkaround Whether to use the workaround for vertical text alignment
     */
    static export(model: IPlotModel, width: number, height: number, isDocument: boolean, textMeasurer?: ITextMeasurer, useVerticalTextAlignmentWorkaround?: boolean): Promise<string>;
    /**
     * Exports to string.
     * @param model The model.
     * @param width The width (points).
     * @param height The height (points).
     * @param isDocument if set to true, the xml headers will be included (?xml and !DOCTYPE).
     * @param textMeasurer The text measurer.
     * @returns The plot as an SVG string.
     * @param useVerticalTextAlignmentWorkaround Whether to use the workaround for vertical text alignment
     */
    static exportToString(model: IPlotModel, width: number, height: number, isDocument: boolean, textMeasurer?: ITextMeasurer, useVerticalTextAlignmentWorkaround?: boolean): Promise<string>;
    /**
     * Exports the specified PlotModel to a Stream.
     * @param model The model to export.
     */
    export(model: IPlotModel): Promise<ArrayBuffer>;
    /**
     * Exports the specified PlotModel to a string.
     * @param model The model.
     * @returns the SVG content as a string.
     */
    exportToString(model: IPlotModel): Promise<string>;
}
//# sourceMappingURL=SvgExporter.d.ts.map