import type { IDisposable } from 'oxyplot-js';
/**
 * Provides an abstract base class for exporters that write xml.
 */
export declare abstract class XmlWriterBase implements IDisposable {
    private _no;
    /**
     * The xml writer.
     */
    private w;
    private readonly _stream?;
    private _xml;
    /**
     * Initializes a new instance of the XmlWriterBase class.
     * @param stream The stream.
     */
    protected constructor(stream?: WritableStream);
    /**
     * Closes this instance.
     */
    close(): void;
    /**
     * Flushes this instance.
     */
    flush(): void;
    getXml(): string;
    /**
     * Writes an attribute string.
     * @param name The name.
     * @param value The value.
     */
    protected writeAttributeString(name: string, value: string): void;
    /**
     * Writes an attribute string with a prefix.
     * @param prefix The prefix.
     * @param name The name.
     * @param ns The constant.
     * @param value The value.
     */
    protected writeAttributeString2(prefix: string, name: string, ns: string, value: string): void;
    /**
     * Writes the doc type.
     * @param name The name of the DOCTYPE. This must be non-empty.
     * @param pubid If non-null it also writes PUBLIC "pubid" "sysid" where pubid and sysid are replaced with the value of the given arguments.
     * @param sysid If pubid is null and sysid is non-null it writes SYSTEM "sysid" where sysid is replaced with the value of this argument.
     * @param subset If non-null it writes [subset] where subset is replaced with the value of this argument.
     */
    protected writeDocType(name: string, pubid?: string, sysid?: string, subset?: string): void;
    /**
     * Writes an element string.
     * @param name The name.
     * @param text The text.
     */
    protected writeElementString(name: string, text: string): void;
    /**
     * Writes the end document.
     */
    protected writeEndDocument(): void;
    /**
     * Writes an element end tag.
     */
    protected writeEndElement(): void;
    /**
     * Writes raw text.
     * @param text The text.
     */
    protected writeRaw(text: string): void;
    /**
     * Writes the start document.
     * @param standalone The standalone.
     */
    protected writeStartDocument(standalone: boolean): void;
    /**
     * Writes an element start tag.
     * @param name The name.
     * @param ns The ns.
     */
    protected writeStartElement(name: string, ns?: string): void;
    /**
     * Writes a string.
     * @param text The text.
     */
    protected writeString(text: string): void;
    private _disposed;
    dispose(): void;
}
//# sourceMappingURL=XmlWriterBase.d.ts.map